body {
    display: flex;
    flex-direction: column;
    min-height: 100vh;
}
.page-wrapper {
    flex-grow: 1;
}
.navbar-brand-image {
    height: 2rem;
}
/* Make modals more prominent */
.modal-content {
    border-radius: 0.5rem;
    box-shadow: 0 8px 30px rgba(0, 0, 0, 0.12);
}
/* Custom styles to improve UX */
.cursor-pointer {
    cursor: pointer;
}
.page-center .card {
    width: 100%;
    max-width: 400px;
}